@@ -39,10 +39,10 @@ Please note that Rex may set the C<PATH> environment variable when executing com
 
 package Rex::Commands::Run;
 
-use v5.12.5;
+use v5.14.4;
 use warnings;
 
-our $VERSION = '1.15.0.2'; # TRIAL VERSION
+our $VERSION = '1.16.0.1'; # TRIAL VERSION
 
 #require Exporter;
 require Rex::Exporter;
@@ -133,7 +133,7 @@ Die if the command returns with an exit code indicating failure. It can be set g
 
 =item command => $command_to_run
 
-If present, Rex will execute C<$command_to_run>, and treat the first arugment as an identifier for the given C<run()> block (e.g. to be triggered with notify).
+If present, Rex will execute C<$command_to_run>, and treat the first argument as an identifier for the given C<run()> block (e.g. to be triggered with notify).
 
 =item creates => $file_to_create
 
