@@ -4,10 +4,10 @@
 
 package Rex::Group;
 
-use v5.12.5;
+use v5.14.4;
 use warnings;
 
-our $VERSION = '1.15.0.2'; # TRIAL VERSION
+our $VERSION = '1.16.0.1'; # TRIAL VERSION
 
 use Rex::Logger;
 
@@ -15,7 +15,7 @@ use attributes;
 use Rex::Group::Entry::Server;
 
 use vars qw(%groups);
-use List::Util 1.45 qw(uniq);
+use List::Util 1.45 qw(any uniq);
 use Data::Dumper;
 
 sub new {
@@ -24,8 +24,16 @@ sub new {
   my $self  = {@_};
 
   bless( $self, $proto );
+
   for my $srv ( @{ $self->{servers} } ) {
     $srv->append_to_group( $self->{name} );
+
+    for my $group ( keys %groups ) {
+
+      if ( any { $_ eq $srv } $groups{$group}->get_servers ) {
+        $srv->append_to_group($group);
+      }
+    }
   }
 
   return $self;
