@@ -4,10 +4,10 @@
 
 package Rex::Hardware::Memory;
 
-use v5.12.5;
+use v5.14.4;
 use warnings;
 
-our $VERSION = '1.15.0.2'; # TRIAL VERSION
+our $VERSION = '1.16.0.1'; # TRIAL VERSION
 
 use English qw(-no_match_vars);
 use Rex::Hardware::Host;
@@ -58,7 +58,8 @@ sub get {
     if ( $CHILD_ERROR == 0 ) {
       my ($free_cache) =
         map { /\D+\d+\s+(\d+)/ } grep { /^Free \(cache/ } @data;
-      my ($free_list) = map { /\D+\d+\s+(\d+)/ } grep { /^Free \(freel/ } @data;
+      my ($free_list) =
+        map { /\D+\d+\s+(\d+)/ } grep { /^Free (\s+|\(freel)/ } @data;
       my ($page_cache) = map { /\s+\d+\s+(\d+)/ } grep { /^Page cache/ } @data;
 
       my $free = $free_cache + $free_list;
@@ -134,37 +135,32 @@ sub get {
     my $mem_str   = i_run "top -d1 | grep Mem:", fail_ok => 1;
     my $total_mem = sysctl("hw.physmem");
 
-    my (
-      $active, $a_ent, $inactive, $i_ent, $wired, $w_ent,
-      $cache,  $c_ent, $buf,      $b_ent, $free,  $f_ent
-      )
-      = ( $mem_str =~
-        m/(\d+)([a-z])[^\d]+(\d+)([a-z])[^\d]+(\d+)([a-z])[^\d]+(\d+)([a-z])[^\d]+(\d+)([a-z])[^\d]+(\d+)([a-z])/i
-      );
+    my $memory_details = __parse_top_output($mem_str);
 
-    if ( !$active ) {
-      (
-        $active, $a_ent, $inactive, $i_ent, $wired,
-        $w_ent,  $buf,   $b_ent,    $free,  $f_ent
-        )
-        = ( $mem_str =~
-          m/(\d+)([a-z])[^\d]+(\d+)([a-z])[^\d]+(\d+)([a-z])[^\d]+(\d+)([a-z])[^\d]+(\d+)([a-z])/i
-        );
+    for my $stat (qw(active inactive wired laundry cache buf free)) {
+
+      if ( exists $memory_details->{$stat} ) {
+
+        my ( $value, $unit ) = $memory_details->{$stat} =~ qr{(\d+)([KMG])}msx;
+
+        $memory_details->{$stat} = $value;
+
+        &$convert( $memory_details->{$stat}, $unit );
+      }
+      else {
+        $memory_details->{$stat} = 0;
+      }
     }
 
-    &$convert( $active,   $a_ent );
-    &$convert( $inactive, $i_ent );
-    &$convert( $wired,    $w_ent ) if ($wired);
-    &$convert( $cache,    $c_ent ) if ($cache);
-    &$convert( $buf,      $b_ent ) if ($buf);
-    &$convert( $free,     $f_ent );
-
     $data = {
-      total   => $total_mem,
-      used    => $active + $inactive + $wired,
-      free    => $free,
-      cached  => $cache,
-      buffers => $buf,
+      total => $total_mem,
+      used  => $memory_details->{active} +
+        $memory_details->{inactive} +
+        $memory_details->{wired} +
+        $memory_details->{laundry},
+      free    => $memory_details->{free},
+      cached  => $memory_details->{cache},
+      buffers => $memory_details->{buf},
     };
   }
   elsif ( $os eq "OpenWrt" ) {
@@ -233,4 +229,28 @@ sub get {
   return $data;
 }
 
+sub __parse_top_output {
+  my $top_output = shift;
+
+  my @matches = $top_output =~ m{
+        \d+   # one or more digits
+        [KMG] # unit
+        [ ]   # space
+        \w+   # memory use type
+    }gmsx;
+
+  @matches = map { split qr{[ ]}msx } @matches;
+
+  if ( $matches[0] =~ qr{\d}msx ) {
+    @matches = reverse @matches;
+  }
+
+  my %top_memory_data = @matches;
+
+  %top_memory_data =
+    map { lc $_ => $top_memory_data{$_} } keys %top_memory_data;
+
+  return \%top_memory_data;
+}
+
 1;
